@@ -7,13 +7,18 @@
 ### dependencies: library(sets)
 ###
 ### 2008-04-24: created
+### 2017-12-13: Allowing kbase parameter
 ###
 
 katoms <- function(x, items) {
 
    ### check x
-   if (!inherits(x, "kstructure")) {
-      stop(sprintf("%s must be of class %s.", dQuote("x"), dQuote("kstructure")))
+   if (!inherits(x, "kstructure") & !inherits(x, "kbase")) {
+      stop(sprintf("%s must be of class %s or %s.", 
+        dQuote("x"), 
+	dQuote("kstructure"),
+	dQuote("kbase")
+      ))
    }
 
    ### check items
@@ -26,7 +31,8 @@ katoms <- function(x, items) {
    atoms <- list()
    items <- as.set(lapply(items, as.character))
    for (i in items) {
-      states <- x[grep(i,x)]
+#      states <- x[grep(i,x)]
+     states <- x[which(sapply(x, function(j) grep(i,j))!=0)]
       atom <- set()
       for (j in seq_along(states)) {
          subsets <- lapply(states[-j],set_is_subset, states[[j]])
